@@ -23,7 +23,7 @@ KAboutData kalziumGLPartAboutData()
     KAboutData aboutData(
         "kalzium", QByteArray(), ki18n("Kalzium OpenGL Part"), "1.1.1",
         ki18n("A cool thing"),
-        KAboutData::License_GPL, ki18n("(c) 2006, Carsten Niehaus"),
+        KAboutLicense::GPL, ki18n("(c) 2006, Carsten Niehaus"),
         KLocalizedString(),
         "http://edu.kde.org/kalzium/index.php"
     );
@@ -41,7 +41,7 @@ KalziumGLPart::KalziumGLPart(QWidget* parentWidget, QObject* parent, const QVari
     Q_UNUSED(parent);
     Q_UNUSED(parentWidget);
     Q_UNUSED(args);
-    kDebug() << "KalziumGLPart::KalziumGLPart()";
+    qDebug() << "KalziumGLPart::KalziumGLPart()";
 
     m_widget = new KalziumGLWidget();
     m_widget->setObjectName("KalziumGLWidget-KPart");
@@ -50,7 +50,7 @@ KalziumGLPart::KalziumGLPart(QWidget* parentWidget, QObject* parent, const QVari
 KalziumGLPart::~KalziumGLPart()
 {
     delete m_widget;
-    kDebug() << "KalziumGLPart::~KalziumGLPart()";
+    qDebug() << "KalziumGLPart::~KalziumGLPart()";
 }
 
 bool KalziumGLPart::openFile()
