@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright (C) 2006 by Carsten Niehau                                  *
+ *   copyright (C) 2006 by Carsten Niehaus  cniehaus@kde.org               *
  *   Copyright (C) 2010 by Etienne Rebetez  etienne.rebetez@oberwallis.ch  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ public:
      * @param elementProperty The elementProperty class
      * @param parent The parent of this widget
      */
-    GradientWidgetImpl(QWidget *parent = 0);
+    GradientWidgetImpl(QWidget *parent = nullptr);
     virtual ~GradientWidgetImpl();
 
 Q_SIGNALS:
