@@ -2,8 +2,8 @@
  NumerationItem - Numeration Item, part of the Periodic Table Graphics View
  for Kalzium
 
- Copyright (C) 2007-2009 by Marcus D. Hanwell
- Copyright (C) 2010      by Etienne Rebetez
+ Copyright (C) 2007-2009 by Marcus D. Hanwell marcus@cryos.org
+ Copyright (C) 2010      by Etienne Rebetez etienne.rebetez@oberwallis.ch
 
  This file is part of the Avogadro molecular editor project.
  For more information, see <http://avogadro.openmolecules.net/>
@@ -59,18 +59,18 @@ public:
     /**
      * @return the bounding rectangle of the element item.
      */
-    QRectF boundingRect() const;
+    QRectF boundingRect() const override;
 
     /**
      * @return the painter path which is also a rectangle in this case.
      */
-    QPainterPath shape() const;
+    QPainterPath shape() const override;
 
     /**
      * This is where most of the action takes place. The element box is drawn
      * along with its symbol.
      */
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
 
 public Q_SLOTS:
     void setNumerationType(int type);
